@@ -70,6 +70,21 @@ class FastbotManager:
             "/data/local/tmp/x86_64/libfastbot_native.so",
         )
 
+        whitelist = self.options.act_whitelist_file
+        blacklist = self.options.act_blacklist_file
+        if bool(whitelist) ^ bool(blacklist):
+            if whitelist:
+                file_to_push = cur_dir.parent / 'configs' / 'awl.strings'
+                remote_path = whitelist
+            else:
+                file_to_push = cur_dir.parent / 'configs' / 'abl.strings'
+                remote_path = blacklist
+
+            self.dev.sync.push(
+                file_to_push,
+                remote_path
+            )
+
         t = self._startFastbotService()
         logger.info("Running Fastbot...")
 
@@ -167,6 +182,14 @@ class FastbotManager:
         if self.options.profile_period:
             shell_command += ["--profile-period", f"{self.options.profile_period}"]
 
+        whitelist = self.options.act_whitelist_file
+        blacklist = self.options.act_blacklist_file
+        if bool(whitelist) ^ bool(blacklist):
+            if whitelist:
+                shell_command += ["--act-whitelist-file", f"{whitelist}"]
+            else:
+                shell_command += ["--act-blacklist-file", f"{blacklist}"]
+
         shell_command += ["-v", "-v", "-v"]
 
         full_cmd = ["adb"] + (["-s", self.options.serial] if self.options.serial else []) + ["shell"] + shell_command
